"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentManager = void 0;
const protocol_definitions_1 = require("@fluidframework/protocol-definitions");
const server_services_client_1 = require("@fluidframework/server-services-client");
const server_services_utils_1 = require("@fluidframework/server-services-utils");
/**
 * Manager to fetch document from Alfred using the internal URL.
 */
class DocumentManager {
    constructor(internalAlfredUrl, tenantManager) {
        this.internalAlfredUrl = internalAlfredUrl;
        this.tenantManager = tenantManager;
    }
    async readDocument(tenantId, documentId) {
        const restWrapper = await this.getBasicRestWrapper(tenantId, documentId);
        return restWrapper.get(`/documents/${tenantId}/${documentId}`);
    }
    async getBasicRestWrapper(tenantId, documentId) {
        const key = await this.tenantManager.getKey(tenantId);
        const getDefaultHeaders = () => {
            const jwtToken = (0, server_services_utils_1.generateToken)(tenantId, documentId, key, [protocol_definitions_1.ScopeType.DocRead]);
            return {
                Authorization: `Basic ${jwtToken}`,
            };
        };
        const restWrapper = new server_services_client_1.BasicRestWrapper(this.internalAlfredUrl, undefined /* defaultQueryString */, undefined /* maxBodyLength */, undefined /* maxContentLength */, getDefaultHeaders(), undefined /* Axios */, undefined /* refreshDefaultQueryString */, getDefaultHeaders /* refreshDefaultHeaders */, server_services_utils_1.getCorrelationId /* getCorrelationId */);
        return restWrapper;
    }
}
exports.DocumentManager = DocumentManager;
//# sourceMappingURL=documentManager.js.map