"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMongoNetworkErrorRetryRuleset = void 0;
const IMongoExceptionRetryRule_1 = require("../IMongoExceptionRetryRule");
class MongoNetworkTransientTransactionError extends IMongoExceptionRetryRule_1.BaseMongoExceptionRetryRule {
    constructor(retryRuleOverride) {
        super("MongoNetworkTransientTransactionError", retryRuleOverride);
        this.defaultRetryDecision = true;
    }
    match(error) {
        var _a;
        return (((_a = error.errorLabels) === null || _a === void 0 ? void 0 : _a.length) &&
            error.errorLabels.includes("TransientTransactionError"));
    }
}
class MongoNetworkConnectionClosedError extends IMongoExceptionRetryRule_1.BaseMongoExceptionRetryRule {
    constructor(retryRuleOverride) {
        super("MongoNetworkConnectionClosedError", retryRuleOverride);
        this.defaultRetryDecision = true;
    }
    match(error) {
        return (error.message && /^connection .+ closed$/.test(error.message) === true // matches any message of format "connection <some-info> closed"
        );
    }
}
class MongoNetworkSocketDisconnectedError extends IMongoExceptionRetryRule_1.BaseMongoExceptionRetryRule {
    constructor(retryRuleOverride) {
        super("MongoNetworkSocketDisconnectedError", retryRuleOverride);
        this.defaultRetryDecision = true;
    }
    match(error) {
        return (error.message &&
            error.message === MongoNetworkSocketDisconnectedError.errorMessage);
    }
}
MongoNetworkSocketDisconnectedError.errorMessage = "Client network socket disconnected before secure TLS connection was established";
// Maintain the list from more strick faster comparison to less strict slower comparison
function createMongoNetworkErrorRetryRuleset(retryRuleOverride) {
    const mongoNetworkErrorRetryRuleset = [
        new MongoNetworkTransientTransactionError(retryRuleOverride),
        new MongoNetworkConnectionClosedError(retryRuleOverride),
        new MongoNetworkSocketDisconnectedError(retryRuleOverride),
    ];
    return mongoNetworkErrorRetryRuleset;
}
exports.createMongoNetworkErrorRetryRuleset = createMongoNetworkErrorRetryRuleset;
//# sourceMappingURL=index.js.map